.. _local_min:

#####################
Local Minimizer Table
#####################

.. currentmodule:: fitbenchmarking.results_processing.local_min_table
.. autoclass:: fitbenchmarking.results_processing.local_min_table.LocalMinTable
	       :noindex:
